@@ -14,14 +14,14 @@ def _get_kwargs(
     app_id: str,
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/app/{app_id}/".format(client.base_url, app_id=app_id)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    if not isinstance(idempotency_key, Unset):
+    if not isinstance(idempotency_key, Unset) and idempotency_key is not None:
         headers["idempotency-key"] = idempotency_key
 
     return {
@@ -58,7 +58,7 @@ def sync_detailed(
     app_id: str,
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> None:
     """Delete Application
 
@@ -66,7 +66,7 @@ def sync_detailed(
 
     Args:
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         None
@@ -101,7 +101,7 @@ def sync(
     app_id: str,
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> None:
     """Delete Application
 
@@ -109,7 +109,7 @@ def sync(
 
     Args:
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         None
@@ -126,7 +126,7 @@ async def asyncio_detailed(
     app_id: str,
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> None:
     """Delete Application
 
@@ -134,7 +134,7 @@ async def asyncio_detailed(
 
     Args:
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         None
@@ -167,7 +167,7 @@ async def asyncio(
     app_id: str,
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> None:
     """Delete Application
 
@@ -175,7 +175,7 @@ async def asyncio(
 
     Args:
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         None
