@@ -18,14 +18,14 @@ def _get_kwargs(
     client: AuthenticatedClient,
     iterator: Union[Unset, None, str] = UNSET,
     limit: Union[Unset, None, int] = 50,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/app/{app_id}/msg/{msg_id}/endpoint/".format(client.base_url, app_id=app_id, msg_id=msg_id)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    if not isinstance(idempotency_key, Unset):
+    if not isinstance(idempotency_key, Unset) and idempotency_key is not None:
         headers["idempotency-key"] = idempotency_key
 
     params: Dict[str, Any] = {}
@@ -74,7 +74,7 @@ def sync_detailed(
     client: AuthenticatedClient,
     iterator: Union[Unset, None, str] = UNSET,
     limit: Union[Unset, None, int] = 50,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseMessageEndpointOut:
     """List Attempted Destinations
 
@@ -85,7 +85,7 @@ def sync_detailed(
         msg_id (str): The message's ID or eventID Example: msg_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         iterator (Union[Unset, None, str]):  Example: msgep_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         limit (Union[Unset, None, int]):  Default: 50.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseMessageEndpointOut
@@ -126,7 +126,7 @@ def sync(
     client: AuthenticatedClient,
     iterator: Union[Unset, None, str] = UNSET,
     limit: Union[Unset, None, int] = 50,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseMessageEndpointOut:
     """List Attempted Destinations
 
@@ -137,7 +137,7 @@ def sync(
         msg_id (str): The message's ID or eventID Example: msg_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         iterator (Union[Unset, None, str]):  Example: msgep_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         limit (Union[Unset, None, int]):  Default: 50.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseMessageEndpointOut
@@ -160,7 +160,7 @@ async def asyncio_detailed(
     client: AuthenticatedClient,
     iterator: Union[Unset, None, str] = UNSET,
     limit: Union[Unset, None, int] = 50,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseMessageEndpointOut:
     """List Attempted Destinations
 
@@ -171,7 +171,7 @@ async def asyncio_detailed(
         msg_id (str): The message's ID or eventID Example: msg_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         iterator (Union[Unset, None, str]):  Example: msgep_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         limit (Union[Unset, None, int]):  Default: 50.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseMessageEndpointOut
@@ -210,7 +210,7 @@ async def asyncio(
     client: AuthenticatedClient,
     iterator: Union[Unset, None, str] = UNSET,
     limit: Union[Unset, None, int] = 50,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseMessageEndpointOut:
     """List Attempted Destinations
 
@@ -221,7 +221,7 @@ async def asyncio(
         msg_id (str): The message's ID or eventID Example: msg_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         iterator (Union[Unset, None, str]):  Example: msgep_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         limit (Union[Unset, None, int]):  Default: 50.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseMessageEndpointOut
