@@ -57,7 +57,7 @@ class EventTypeIn:
 
         archived = dict_copy.pop("archived", UNSET)
 
-        schemas = dict_copy.pop("schemas")
+        schemas = dict_copy.pop("schemas", UNSET)
 
         event_type_in = cls(
             description=description,
