@@ -73,7 +73,7 @@ class EventTypeOut:
 
         archived = dict_copy.pop("archived", UNSET)
 
-        schemas = dict_copy.pop("schemas")
+        schemas = dict_copy.pop("schemas", UNSET)
 
         event_type_out = cls(
             created_at=created_at,
